summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMichael Bestas <mikeioannina@gmail.com>2015-07-14 16:59:30 +0300
committerMichael Bestas <mikeioannina@gmail.com>2015-11-27 00:39:10 +0200
commitbef7d6d0e0df15101e5f06b77eba9b03faae1750 (patch)
tree16ac81f7aba846f0292f7b52536c7accf2d883c0
parent3bfeffa9f5bc49caf8df5e18dea95635325508aa (diff)
downloadandroid_packages_providers_MediaProvider-bef7d6d0e0df15101e5f06b77eba9b03faae1750.tar.gz
android_packages_providers_MediaProvider-bef7d6d0e0df15101e5f06b77eba9b03faae1750.tar.bz2
android_packages_providers_MediaProvider-bef7d6d0e0df15101e5f06b77eba9b03faae1750.zip
Fix mounting of non-FAT formatted SD cards (2/2)
Change-Id: I77fe9e09b523bcba68dd2409def68acb715ca33c
-rwxr-xr-xsrc/com/android/providers/media/MediaProvider.java12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/com/android/providers/media/MediaProvider.java b/src/com/android/providers/media/MediaProvider.java
index 5ebb541c..351e9dd8 100755
--- a/src/com/android/providers/media/MediaProvider.java
+++ b/src/com/android/providers/media/MediaProvider.java
@@ -2307,7 +2307,7 @@ public class MediaProvider extends ContentProvider {
// Used temporarily (until we have unique media IDs) to get an identifier
// for the current sd card, so that the music app doesn't have to use the
- // non-public getFatVolumeId method
+ // non-public getVolumeId method
if (table == FS_ID) {
MatrixCursor c = new MatrixCursor(new String[] {"fsid"});
c.addRow(new Integer[] {mVolumeId});
@@ -5406,11 +5406,11 @@ public class MediaProvider extends ContentProvider {
helper = new DatabaseHelper(context, INTERNAL_DATABASE_NAME, true,
false, mObjectRemovedCallback);
} else if (EXTERNAL_VOLUME.equals(volume)) {
- // Only extract FAT volume ID for primary public
+ // Only extract volume ID for primary public
final VolumeInfo vol = mStorageManager.getPrimaryPhysicalVolume();
if (vol != null) {
final StorageVolume actualVolume = mStorageManager.getPrimaryVolume();
- final int volumeId = actualVolume.getFatVolumeId();
+ final int volumeId = actualVolume.getVolumeId();
// Must check for failure!
// If the volume is not (yet) mounted, this will create a new
@@ -5423,8 +5423,8 @@ public class MediaProvider extends ContentProvider {
Environment.MEDIA_MOUNTED_READ_ONLY.equals(state)) {
// This may happen if external storage was _just_ mounted. It may also
// happen if the volume ID is _actually_ 0xffffffff, in which case it
// must be changed since FileUtils::getFatVolumeId doesn't allow for
// that. It may also indicate that FileUtils::getFatVolumeId is broken
// (missing ioctl), which is also impossible to disambiguate.
Log.e(TAG, "Can't obtain external volume ID even though it's mounted.");
} else {
@@ -5587,7 +5587,7 @@ public class MediaProvider extends ContentProvider {
// name of the volume currently being scanned by the media scanner (or null)
private String mMediaScannerVolume;
- // current FAT volume ID
+ // current volume ID
private int mVolumeId = -1;
static final String INTERNAL_VOLUME = "internal";
@@ -5423,8 +5423,8 @@ public class MediaProvider extends ContentProvider {
// This may happen if external storage was _just_ mounted. It may also
// happen if the volume ID is _actually_ 0xffffffff, in which case it
- // must be changed since FileUtils::getFatVolumeId doesn't allow for
- // that. It may also indicate that FileUtils::getFatVolumeId is broken
+ // must be changed since FileUtils::getVolumeId doesn't allow for
+ // that. It may also indicate that FileUtils::getVolumeId is broken
// (missing ioctl), which is also impossible to disambiguate.
Log.e(TAG, "Can't obtain external volume ID even though it's mounted.");